==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24MouseHandler.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel$MouseHandler

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b4f1f8414f70bd23 javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$method$_init$38c158a6ea17da85(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$method_info$mousePressed$0e61f2afd4a13bb2;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vmethods {
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24MouseHandler.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel$MouseHandler

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bd1af974375600be javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$method$_init$38c158a6ea17da85(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$method_info$mousePressed$0e61f2afd4a13bb2;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vmethods {
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MouseHandler_H_ */
